/* This file was generated by syncqt. */
#ifndef QT_QTDATAVISUALIZATIONQML_VERSION_H
#define QT_QTDATAVISUALIZATIONQML_VERSION_H

#define QTDATAVISUALIZATIONQML_VERSION_STR "6.8.2"

#define QTDATAVISUALIZATIONQML_VERSION 0x060802

#endif // QT_QTDATAVISUALIZATIONQML_VERSION_H
